@@ -1,11 +1,13 @@
-import os, shutil
+import os
+import shutil
 from snipper.snipper_main import censor_file
 from pathlib import Path
 import time
 import fnmatch
 import tempfile
+# from line_profiler_pycharm import profile
 
-
+# @profile
 def snip_dir(source_dir,  # Sources
              dest_dir=None,  # Will write to this directory
              output_dir=None, # Where snippets are going to be stored
@@ -14,9 +16,11 @@ def snip_dir(source_dir,  # Sources
              run_files=True,  # Run #!o tags and #!i tags
              cut_files=True,   # censor files.
              license_head=None,
+             censor_files=True,
+             verbose=True,
              ):
 
-
+    print("Snipper fixing", source_dir)
     if dest_dir == None:
         dest_dir = tempfile.mkdtemp()
         print("[snipper]", "no destination dir was specified so using nonsense destination:", dest_dir)
@@ -42,17 +46,17 @@ def snip_dir(source_dir,  # Sources
 
     if clean_destination_dir:
         shutil.rmtree(dest_dir)
-    os.makedirs(dest_dir)
 
+    os.makedirs(dest_dir)
     out = dest_dir
     hw = {'base': source_dir}
-
-    print(f"[snipper] Synchronizing directories: {hw['base']} -> {out}")
+    if verbose:
+        print(f"[snipper]: {hw['base']} -> {out}")
     if os.path.exists(dest_dir):
         shutil.rmtree(dest_dir)
 
     shutil.copytree(source_dir, dest_dir)
-    time.sleep(0.1)
+    time.sleep(0.02)
 
     ls = list(Path(dest_dir).glob('**/*'))
     acceptable = []
@@ -62,21 +66,27 @@ def snip_dir(source_dir,  # Sources
         acceptable.append( (l, not any(m) ))
 
     n = 0
+    cutouts = {}
     for f, accept in acceptable:
         if os.path.isdir(f) or not str(f).endswith(".py") or  str(f).endswith("_grade.py"):
             continue
         if accept:
             solution_list = []
             kwargs = {}
-            nrem = censor_file(f, run_files=run_files, run_out_dirs=output_dir, cut_files=cut_files,
-                               solution_list=solution_list,
+            if verbose:
+                print("Snipper processing", f)
+            nrem, cut = censor_file(f, run_files=run_files, run_out_dirs=output_dir, cut_files=cut_files,
+                               # solution_list=solution_list,
                                base_path=dest_dir,
                                references=references,
                                license_head=license_head,
+                               censor_files=censor_files,
                                **kwargs)
-            if nrem > 0:
+            if nrem > 0 and verbose:
                 print(f"{nrem}> {f}")
+            cutouts[str(f)] = cut
             n += nrem
+
     for rm_file, accept in acceptable:
         rm_file = os.path.abspath(rm_file)
         if not accept:
@@ -85,4 +95,5 @@ def snip_dir(source_dir,  # Sources
             else:
                 if os.path.isdir(rm_file+"/"):
                     shutil.rmtree(rm_file)
-    return n
+    print("[snipper]", "done")
+    return n, cutouts
